==> aws-sdk-1.4.0.tgz: package/lib/services/api/directconnect-2012-10-25.js <==
/**
 * Copyright 2012-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"). You
 * may not use this file except in compliance with the License. A copy of
 * the License is located at
 *
 *     http://aws.amazon.com/apache2.0/
 *
 * or in the "license" file accompanying this file. This file is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 * ANY KIND, either express or implied. See the License for the specific
 * language governing permissions and limitations under the License.
 */

module.exports = {
  format: 'json',
  apiVersion: '2012-10-25',
  endpointPrefix: 'directconnect',
  jsonVersion: '1.1',
  serviceFullName: 'AWS Direct Connect',
  signatureVersion: 'v4',
  targetPrefix: 'OvertureService',
  timestampFormat: 'iso8601',
  operations: {
    createConnection: {
      name: 'CreateConnection',
      input: {
        type: 'structure',
        members: {
          offeringId: {
            required: true
          },
          connectionName: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          connectionId: {
          },
          connectionName: {
          },
          connectionState: {
          },
          region: {
          },
          location: {
          }
        }
      }
    },
    createPrivateVirtualInterface: {
      name: 'CreatePrivateVirtualInterface',
      input: {
        type: 'structure',
        members: {
          connectionId: {
          },
          newPrivateVirtualInterface: {
            type: 'structure',
            members: {
              virtualInterfaceName: {
              },
              vlan: {
                type: 'integer'
              },
              asn: {
                type: 'integer'
              },
              authKey: {
              },
              amazonAddress: {
              },
              customerAddress: {
              },
              virtualGatewayId: {
              }
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          virtualInterfaceId: {
          },
          location: {
          },
          connectionId: {
          },
          virtualInterfaceType: {
          },
          virtualInterfaceName: {
          },
          vlan: {
            type: 'integer'
          },
          asn: {
            type: 'integer'
          },
          authKey: {
          },
          amazonAddress: {
          },
          customerAddress: {
          },
          virtualInterfaceState: {
          },
          customerRouterConfig: {
          },
          virtualGatewayId: {
          },
          routeFilterPrefixes: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                cidr: {
                }
              }
            }
          }
        }
      }
    },
    createPublicVirtualInterface: {
      name: 'CreatePublicVirtualInterface',
      input: {
        type: 'structure',
        members: {
          connectionId: {
          },
          newPublicVirtualInterface: {
            type: 'structure',
            members: {
              virtualInterfaceName: {
              },
              vlan: {
                type: 'integer'
              },
              asn: {
                type: 'integer'
              },
              authKey: {
              },
              amazonAddress: {
              },
              customerAddress: {
              },
              routeFilterPrefixes: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    cidr: {
                    }
                  }
                }
              }
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          virtualInterfaceId: {
          },
          location: {
          },
          connectionId: {
          },
          virtualInterfaceType: {
          },
          virtualInterfaceName: {
          },
          vlan: {
            type: 'integer'
          },
          asn: {
            type: 'integer'
          },
          authKey: {
          },
          amazonAddress: {
          },
          customerAddress: {
          },
          virtualInterfaceState: {
          },
          customerRouterConfig: {
          },
          virtualGatewayId: {
          },
          routeFilterPrefixes: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                cidr: {
                }
              }
            }
          }
        }
      }
    },
    deleteConnection: {
      name: 'DeleteConnection',
      input: {
        type: 'structure',
        members: {
          connectionId: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          connectionId: {
          },
          connectionName: {
          },
          connectionState: {
          },
          region: {
          },
          location: {
          }
        }
      }
    },
    deleteVirtualInterface: {
      name: 'DeleteVirtualInterface',
      input: {
        type: 'structure',
        members: {
          virtualInterfaceId: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          virtualInterfaceState: {
          }
        }
      }
    },
    describeConnectionDetail: {
      name: 'DescribeConnectionDetail',
      input: {
        type: 'structure',
        members: {
          connectionId: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          connectionId: {
          },
          connectionName: {
          },
          connectionState: {
          },
          region: {
          },
          location: {
          },
          bandwidth: {
          },
          connectionCosts: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                name: {
                },
                unit: {
                },
                currencyCode: {
                },
                amount: {
                }
              }
            }
          },
          orderSteps: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                number: {
                },
                name: {
                },
                description: {
                },
                owner: {
                },
                sla: {
                  type: 'integer'
                },
                stepState: {
                }
              }
            }
          }
        }
      }
    },
    describeConnections: {
      name: 'DescribeConnections',
      input: {
        type: 'structure',
        members: {
          connectionId: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          connections: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                connectionId: {
                },
                connectionName: {
                },
                connectionState: {
                },
                region: {
                },
                location: {
                }
              }
            }
          }
        }
      }
    },
    describeOfferingDetail: {
      name: 'DescribeOfferingDetail',
      input: {
        type: 'structure',
        members: {
          offeringId: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          offeringId: {
          },
          region: {
          },
          location: {
          },
          offeringName: {
          },
          description: {
          },
          bandwidth: {
          },
          connectionCosts: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                name: {
                },
                unit: {
                },
                currencyCode: {
                },
                amount: {
                }
              }
            }
          },
          orderSteps: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                number: {
                },
                name: {
                },
                description: {
                },
                owner: {
                },
                sla: {
                  type: 'integer'
                }
              }
            }
          }
        }
      }
    },
    describeOfferings: {
      name: 'DescribeOfferings',
      input: {
        type: 'structure',
        members: {
        }
      },
      output: {
        type: 'structure',
        members: {
          offerings: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                offeringId: {
                },
                region: {
                },
                location: {
                },
                offeringName: {
                },
                description: {
                },
                bandwidth: {
                },
                connectionCosts: {
                  type: 'list',
                  members: {
                    type: 'structure',
                    members: {
                      name: {
                      },
                      unit: {
                      },
                      currencyCode: {
                      },
                      amount: {
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    },
    describeVirtualGateways: {
      name: 'DescribeVirtualGateways',
      input: {
        type: 'structure',
        members: {
        }
      },
      output: {
        type: 'structure',
        members: {
          virtualGateways: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                virtualGatewayId: {
                },
                virtualGatewayState: {
                }
              }
            }
          }
        }
      }
    },
    describeVirtualInterfaces: {
      name: 'DescribeVirtualInterfaces',
      input: {
        type: 'structure',
        members: {
          connectionId: {
          },
          virtualInterfaceId: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          virtualInterfaces: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                virtualInterfaceId: {
                },
                location: {
                },
                connectionId: {
                },
                virtualInterfaceType: {
                },
                virtualInterfaceName: {
                },
                vlan: {
                  type: 'integer'
                },
                asn: {
                  type: 'integer'
                },
                authKey: {
                },
                amazonAddress: {
                },
                customerAddress: {
                },
                virtualInterfaceState: {
                },
                customerRouterConfig: {
                },
                virtualGatewayId: {
                },
                routeFilterPrefixes: {
                  type: 'list',
                  members: {
                    type: 'structure',
                    members: {
                      cidr: {
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  },
  pagination: {
    describeConnections: {
      resultKey: 'connections'
    },
    describeOfferings: {
      resultKey: 'offerings'
    },
    describeVirtualGateways: {
      resultKey: 'virtualGateways'
    },
    describeVirtualInterfaces: {
      resultKey: 'virtualInterfaces'
    }
  }
};

==> aws-sdk-1.14.0.tgz: package/lib/services/api/directconnect-2012-10-25.js <==
/**
 * Copyright 2012-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"). You
 * may not use this file except in compliance with the License. A copy of
 * the License is located at
 *
 *     http://aws.amazon.com/apache2.0/
 *
 * or in the "license" file accompanying this file. This file is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 * ANY KIND, either express or implied. See the License for the specific
 * language governing permissions and limitations under the License.
 */

module.exports = {
  format: 'json',
  apiVersion: '2012-10-25',
  endpointPrefix: 'directconnect',
  jsonVersion: '1.1',
  serviceFullName: 'AWS Direct Connect',
  signatureVersion: 'v4',
  targetPrefix: 'OvertureService',
  timestampFormat: 'iso8601',
  operations: {
    allocateConnectionOnInterconnect: {
      name: 'AllocateConnectionOnInterconnect',
      input: {
        type: 'structure',
        members: {
          bandwidth: {
            required: true
          },
          connectionName: {
            required: true
          },
          ownerAccount: {
            required: true
          },
          interconnectId: {
            required: true
          },
          vlan: {
            type: 'integer',
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          ownerAccount: {
          },
          connectionId: {
          },
          connectionName: {
          },
          connectionState: {
          },
          region: {
          },
          location: {
          },
          bandwidth: {
          },
          vlan: {
            type: 'integer'
          },
          partnerName: {
          }
        }
      }
    },
    allocatePrivateVirtualInterface: {
      name: 'AllocatePrivateVirtualInterface',
      input: {
        type: 'structure',
        members: {
          connectionId: {
            required: true
          },
          ownerAccount: {
            required: true
          },
          newPrivateVirtualInterfaceAllocation: {
            type: 'structure',
            members: {
              virtualInterfaceName: {
                required: true
              },
              vlan: {
                type: 'integer',
                required: true
              },
              asn: {
                type: 'integer',
                required: true
              },
              authKey: {
              },
              amazonAddress: {
              },
              customerAddress: {
              }
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          ownerAccount: {
          },
          virtualInterfaceId: {
          },
          location: {
          },
          connectionId: {
          },
          virtualInterfaceType: {
          },
          virtualInterfaceName: {
          },
          vlan: {
            type: 'integer'
          },
          asn: {
            type: 'integer'
          },
          authKey: {
          },
          amazonAddress: {
          },
          customerAddress: {
          },
          virtualInterfaceState: {
          },
          customerRouterConfig: {
          },
          virtualGatewayId: {
          },
          routeFilterPrefixes: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                cidr: {
                }
              }
            }
          }
        }
      }
    },
    allocatePublicVirtualInterface: {
      name: 'AllocatePublicVirtualInterface',
      input: {
        type: 'structure',
        members: {
          connectionId: {
            required: true
          },
          ownerAccount: {
            required: true
          },
          newPublicVirtualInterfaceAllocation: {
            type: 'structure',
            members: {
              virtualInterfaceName: {
                required: true
              },
              vlan: {
                type: 'integer',
                required: true
              },
              asn: {
                type: 'integer',
                required: true
              },
              authKey: {
              },
              amazonAddress: {
                required: true
              },
              customerAddress: {
                required: true
              },
              routeFilterPrefixes: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    cidr: {
                    }
                  }
                },
                required: true
              }
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          ownerAccount: {
          },
          virtualInterfaceId: {
          },
          location: {
          },
          connectionId: {
          },
          virtualInterfaceType: {
          },
          virtualInterfaceName: {
          },
          vlan: {
            type: 'integer'
          },
          asn: {
            type: 'integer'
          },
          authKey: {
          },
          amazonAddress: {
          },
          customerAddress: {
          },
          virtualInterfaceState: {
          },
          customerRouterConfig: {
          },
          virtualGatewayId: {
          },
          routeFilterPrefixes: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                cidr: {
                }
              }
            }
          }
        }
      }
    },
    confirmConnection: {
      name: 'ConfirmConnection',
      input: {
        type: 'structure',
        members: {
          connectionId: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          connectionState: {
          }
        }
      }
    },
    confirmPrivateVirtualInterface: {
      name: 'ConfirmPrivateVirtualInterface',
      input: {
        type: 'structure',
        members: {
          virtualInterfaceId: {
            required: true
          },
          virtualGatewayId: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          virtualInterfaceState: {
          }
        }
      }
    },
    confirmPublicVirtualInterface: {
      name: 'ConfirmPublicVirtualInterface',
      input: {
        type: 'structure',
        members: {
          virtualInterfaceId: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          virtualInterfaceState: {
          }
        }
      }
    },
    createConnection: {
      name: 'CreateConnection',
      input: {
        type: 'structure',
        members: {
          location: {
            required: true
          },
          bandwidth: {
            required: true
          },
          connectionName: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          ownerAccount: {
          },
          connectionId: {
          },
          connectionName: {
          },
          connectionState: {
          },
          region: {
          },
          location: {
          },
          bandwidth: {
          },
          vlan: {
            type: 'integer'
          },
          partnerName: {
          }
        }
      }
    },
    createInterconnect: {
      name: 'CreateInterconnect',
      input: {
        type: 'structure',
        members: {
          interconnectName: {
            required: true
          },
          bandwidth: {
            required: true
          },
          location: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          interconnectId: {
          },
          interconnectName: {
          },
          interconnectState: {
          },
          region: {
          },
          location: {
          },
          bandwidth: {
          }
        }
      }
    },
    createPrivateVirtualInterface: {
      name: 'CreatePrivateVirtualInterface',
      input: {
        type: 'structure',
        members: {
          connectionId: {
            required: true
          },
          newPrivateVirtualInterface: {
            type: 'structure',
            members: {
              virtualInterfaceName: {
                required: true
              },
              vlan: {
                type: 'integer',
                required: true
              },
              asn: {
                type: 'integer',
                required: true
              },
              authKey: {
              },
              amazonAddress: {
              },
              customerAddress: {
              },
              virtualGatewayId: {
                required: true
              }
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          ownerAccount: {
          },
          virtualInterfaceId: {
          },
          location: {
          },
          connectionId: {
          },
          virtualInterfaceType: {
          },
          virtualInterfaceName: {
          },
          vlan: {
            type: 'integer'
          },
          asn: {
            type: 'integer'
          },
          authKey: {
          },
          amazonAddress: {
          },
          customerAddress: {
          },
          virtualInterfaceState: {
          },
          customerRouterConfig: {
          },
          virtualGatewayId: {
          },
          routeFilterPrefixes: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                cidr: {
                }
              }
            }
          }
        }
      }
    },
    createPublicVirtualInterface: {
      name: 'CreatePublicVirtualInterface',
      input: {
        type: 'structure',
        members: {
          connectionId: {
            required: true
          },
          newPublicVirtualInterface: {
            type: 'structure',
            members: {
              virtualInterfaceName: {
                required: true
              },
              vlan: {
                type: 'integer',
                required: true
              },
              asn: {
                type: 'integer',
                required: true
              },
              authKey: {
              },
              amazonAddress: {
                required: true
              },
              customerAddress: {
                required: true
              },
              routeFilterPrefixes: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    cidr: {
                    }
                  }
                },
                required: true
              }
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          ownerAccount: {
          },
          virtualInterfaceId: {
          },
          location: {
          },
          connectionId: {
          },
          virtualInterfaceType: {
          },
          virtualInterfaceName: {
          },
          vlan: {
            type: 'integer'
          },
          asn: {
            type: 'integer'
          },
          authKey: {
          },
          amazonAddress: {
          },
          customerAddress: {
          },
          virtualInterfaceState: {
          },
          customerRouterConfig: {
          },
          virtualGatewayId: {
          },
          routeFilterPrefixes: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                cidr: {
                }
              }
            }
          }
        }
      }
    },
    deleteConnection: {
      name: 'DeleteConnection',
      input: {
        type: 'structure',
        members: {
          connectionId: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          ownerAccount: {
          },
          connectionId: {
          },
          connectionName: {
          },
          connectionState: {
          },
          region: {
          },
          location: {
          },
          bandwidth: {
          },
          vlan: {
            type: 'integer'
          },
          partnerName: {
          }
        }
      }
    },
    deleteInterconnect: {
      name: 'DeleteInterconnect',
      input: {
        type: 'structure',
        members: {
          interconnectId: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          interconnectState: {
          }
        }
      }
    },
    deleteVirtualInterface: {
      name: 'DeleteVirtualInterface',
      input: {
        type: 'structure',
        members: {
          virtualInterfaceId: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          virtualInterfaceState: {
          }
        }
      }
    },
    describeConnections: {
      name: 'DescribeConnections',
      input: {
        type: 'structure',
        members: {
          connectionId: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          connections: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                ownerAccount: {
                },
                connectionId: {
                },
                connectionName: {
                },
                connectionState: {
                },
                region: {
                },
                location: {
                },
                bandwidth: {
                },
                vlan: {
                  type: 'integer'
                },
                partnerName: {
                }
              }
            }
          }
        }
      }
    },
    describeConnectionsOnInterconnect: {
      name: 'DescribeConnectionsOnInterconnect',
      input: {
        type: 'structure',
        members: {
          interconnectId: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          connections: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                ownerAccount: {
                },
                connectionId: {
                },
                connectionName: {
                },
                connectionState: {
                },
                region: {
                },
                location: {
                },
                bandwidth: {
                },
                vlan: {
                  type: 'integer'
                },
                partnerName: {
                }
              }
            }
          }
        }
      }
    },
    describeInterconnects: {
      name: 'DescribeInterconnects',
      input: {
        type: 'structure',
        members: {
          interconnectId: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          interconnects: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                interconnectId: {
                },
                interconnectName: {
                },
                interconnectState: {
                },
                region: {
                },
                location: {
                },
                bandwidth: {
                }
              }
            }
          }
        }
      }
    },
    describeLocations: {
      name: 'DescribeLocations',
      input: {
        type: 'structure',
        members: {
        }
      },
      output: {
        type: 'structure',
        members: {
          locations: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                locationCode: {
                },
                locationName: {
                }
              }
            }
          }
        }
      }
    },
    describeVirtualGateways: {
      name: 'DescribeVirtualGateways',
      input: {
        type: 'structure',
        members: {
        }
      },
      output: {
        type: 'structure',
        members: {
          virtualGateways: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                virtualGatewayId: {
                },
                virtualGatewayState: {
                }
              }
            }
          }
        }
      }
    },
    describeVirtualInterfaces: {
      name: 'DescribeVirtualInterfaces',
      input: {
        type: 'structure',
        members: {
          connectionId: {
          },
          virtualInterfaceId: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          virtualInterfaces: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                ownerAccount: {
                },
                virtualInterfaceId: {
                },
                location: {
                },
                connectionId: {
                },
                virtualInterfaceType: {
                },
                virtualInterfaceName: {
                },
                vlan: {
                  type: 'integer'
                },
                asn: {
                  type: 'integer'
                },
                authKey: {
                },
                amazonAddress: {
                },
                customerAddress: {
                },
                virtualInterfaceState: {
                },
                customerRouterConfig: {
                },
                virtualGatewayId: {
                },
                routeFilterPrefixes: {
                  type: 'list',
                  members: {
                    type: 'structure',
                    members: {
                      cidr: {
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  },
  pagination: {
    describeConnections: {
      resultKey: 'connections'
    },
    describeOfferings: {
      resultKey: 'offerings'
    },
    describeVirtualGateways: {
      resultKey: 'virtualGateways'
    },
    describeVirtualInterfaces: {
      resultKey: 'virtualInterfaces'
    }
  }
};
